Mostrando entradas con la etiqueta User Profile. Mostrar todas las entradas
Mostrando entradas con la etiqueta User Profile. Mostrar todas las entradas

jueves, 8 de enero de 2015

Cambiar la foto de tu perfil con Powershell

Cambien los valores en rojo.

URLMySite: hace referencia al web applicationde MySites

SiglaAD: es la sigla del usuario al cual quieren cambiar la foto

Add-PSSnapin Microsoft.SharePoint.PowerShell -ErrorAction SilentlyContinue
$mySiteUrl = "http://URLMySite"
 
#Connect to the User Profile Manager
$site = Get-SPSite $mySiteUrl
$context = Get-SPServiceContext $site
$profileManager = New-Object Microsoft.Office.Server.UserProfiles.UserProfileManager($context)
$up = $profileManager.GetUserProfile("SiglaAD")
$up["PictureURL"].Value = "http://URLMySite/User Photos/Profile Pictures/SiglaAD_MThumb.jpg"
$up.Commit()
write-host $up.DisplayName" --> ", $up["PictureURL"].Value

sábado, 14 de junio de 2014

Problemas con la creación de Sincronización de Perfiles (Populate Containers time-out issue)

Al crear la conexión de sincronización de perfiles mediante el servicio de User Profile Syncronization, la consulta al AD para buscar los containers de OU´s, se quedaba en estado “Querying” y nunca terminaba.

image

Entonces lo que hice fue buscar en los logs (ULS Log Category: User Profiles) de Sharepoint para ver que estaba pasando. Vi el siguiente mensaje:

image

EditDSServer.PopulateContainers(): System.Threading.ThreadAbortException: Thread was being aborted.   
at System.Web.UI.WebControls.TreeView.CollapseAll()   
at Microsoft.SharePoint.Portal.UserProfiles.AdminUI.EditDSServer._GetContainersAndFillTreeView(LdapConnection ldapConnection, Boolean useOnlyPreferredDomainControllers)   
at Microsoft.SharePoint.Portal.UserProfiles.AdminUI.EditDSServer.PopulateContainers(Object sender, EventArgs args).

Getting Error Message for Exception System.Web.HttpException (0x80004005): Request timed out.

System.Web.HttpException: Request timed out.

Solución:

Import-Module -Name ActiveDirectory

Get-ADObject -Filter { ObjectClass -eq 'organizationalunit' } | Select-Object -Property DistinguishedName

  • Ejecuté lo siguiente a continuación:

$upaAppProxy = Get-SPServiceApplicationProxy | ? {$_.name -like 'User Profile Service Proxy'}
$upaAppProxy.LdapConnectionTimeout = 1800 //valor en segundos
$upaAppProxy.Update()

$upaApp = Get-SPServiceApplication | ? {$_.name -like ‘User Profile Service’}
$upaApp.FIMWebClientTimeOut = 1800000  //valor en milisegundos
upaApp.ImportConnAsyncTimeout
$upaApp.Update()

  • Aumenté el tamaño de connection timeout de los sites de Central Administration y Sharepoint Web Services.

image

  • Aumenté el tamaño de la propiedad httpRuntime en el web.config del site del Central Administration

<httpRuntime maxRequestLength="204800" executionTimeout="999999" />

  • Para finalizar también aumenté la propiedad httpRuntime en el web.config de la siguiente ubicación: %DRIVE%\Program Files\Common Files\Microsoft Shared\Web server extensions\15\TEMPLATE\LAYOUTS

Realizando estos cambios, pude hacer que se muestre las OU´s de nuestro AD, para seleccionar que querer importar.

domingo, 21 de abril de 2013

Links útiles #37 Sharepoint 2013

1-Obtener propiedades del user profile mediante una App

El siguiente link explica como crear una App para Sharepoint 2013 y Sharepoint Online para obtener información del usuario logueado.

Figure 2

http://code.msdn.microsoft.com/officeapps/SharePoint-2013-Work-with-99d43c17

2-Drive / Dropbox a Office 365

El artículo nos explica las diferentes posibilidades de migrar contenido desde Drive de Google y Dropbox a Office 365.

http://sharepoint-community.net/profiles/blogs/office-365-and-google-dropbox-document-import-user-experience

3-Introducción a Duet Enterprise Online con Sharepoint y SAP

http://technet.microsoft.com/en-us/library/dn144962.aspx

Duet Enterprise Online deployment diagram

4-Integración de reportes de PowerView usando PageViewer Web Part

El artículo nos explica como integrar un reporte de PowerView mediante un web part de page viewer y mediante un web part de silverlight

http://blogs.msdn.com/b/himanshu1/archive/2013/03/04/integrate-power-view-with-sharepoint-using-web-parts.aspx

5-Acceder a un Term Store mediante SP.Taxonomy.js

En el link encontrará varios ejemplos del uso de javascript para consumir taxonomías de Sharepoint 2013, mediante la librería SP.Taxonomy.js

http://cann0nf0dder.wordpress.com/2013/04/09/accessing-taxonomy-term-store-with-jsom/

Links útiles #36 Sharepoint 2013

1-Hosted App para agregar un botón en la ribbon en Sharepoint 2013

Este artículo nos ayuda a crear un bóton en la ribbon

http://blog.helloitsliam.com/Lists/Posts/Post.aspx?List=e10cb685-6b5c-4b6c-aaf4-e1d122d57174&ID=112

2-Subir imagen del perfil vía programación

http://lixuan0125.wordpress.com/2013/04/08/upload-user-profile-pictures-programmatically-sharepoint-2013/

3-Comunicaciones cross domain en Apps de Sharepoint 2013

En el siguiente articulo nos mostrará los diferentes tipos de comunicaciones cross domain que puede haber gracias a la apps

http://www.elumenotion.com/Blog/Lists/Posts/Post.aspx?List=64b38372-f170-48e3-9720-d3398b3f211c&ID=181

4-Slipstreaming Patches en Sharepoint 2013

Kurgan 3-29-2013 8-22-05 AM

El siguiente artículo nos explica como realizar updates para instalaciones nuevas mediante la carpeta Update.

http://www.toddklindt.com/blog/Lists/Posts/Post.aspx?List=56f96349-3bb6-4087-94f4-7f95ff4ca81f&ID=403&Web=48e6fdd1-17db-4543-b2f9-6fc7185484fc

5-Call HTTP Web Service action en Sharepoint Designer 2013

image

El siguiente ejemplo nos explica como consumir vía la acción “Call HTTP Web Service” servicios REST de Sharepoint

http://sergeluca.wordpress.com/2013/04/09/calling-the-sharepoint-2013-rest-api-from-a-sharepoint-designer-workflow/

martes, 2 de abril de 2013

Links útiles #33 Sharepoint 2013

1-User profiles vía Javascript SCOM en Sharepoint 2013

image

Este artículo nos explicará como obtener información (propiedades) de usuarios vía javascript API

http://vrdmn.blogspot.com.au/2013/02/sharepoint-2013-working-with-user.html

2-Remote Sharepoint Index Search en Sharepoint 2013

Los siguientes artículos nos explicará como obtener el remote Sharepoint index de otra granja de Sharepoint 2013 o Office 365 (vía OAuth)

image

http://blogs.technet.com/b/speschka/archive/2012/07/23/setting-up-an-oauth-trust-between-farms-in-sharepoint-2013.aspx

http://blogs.technet.com/b/speschka/archive/2013/01/24/getting-a-full-result-set-from-a-remote-sharepoint-index-in-sharepoint-2013.aspx

3-Panel de Refinamiento en Sharepoint 2013

RefinementPanelEdit

El siguiente artículo nos introduce en el panel de refinamiento de Sharepoint 2013, en el display template “Refinement item”

http://benprins.wordpress.com/2013/04/02/sharepoint-2013-search-refinement-panel/

http://aghy.hu/AghyBlog_EN/Lists/Posts/Post.aspx?List=a2d07745-f748-4d3b-9c0d-8a15ff7fea35&ID=181&Web=53c3b316-5b05-47ab-9779-74b30194e68b

http://blogs.msdn.com/b/murads/archive/2013/03/01/using-jquery-and-jqplot-in-your-display-template-to-show-a-piechart-refiner.aspx

http://theressomethingaboutsharepoint.blogspot.com.ar/2012/08/customizing-search-results-ui-in_13.html

4-Desarrollo de Workflows con Office Developer Tool y Visual Studio 2012

El siguiente artículo nos ayuda a crear SharePoint workflow app (Document Approval and Routing Workflow) con Visual Studio 2012.

Full-size version of the screenshot

http://blogs.msdn.com/b/officeapps/archive/2013/03/27/sharepoint-workflow-development-with-office-developer-tools-for-visual-studio-2012.aspx

5-Opciones de hosting para aplicaciones LightSwitch para Sharepoint 2013

El siguiente artículo nos explica las diferentes opciones de hosting On-Premises y Cloud de aplicaciones LightSwitch para Sharepoint 2013

clip_image002

http://blogs.msdn.com/b/lightswitch/archive/2013/04/02/sharepoint-hosting-options-for-lightswitch.aspx

jueves, 21 de marzo de 2013

Links útiles #28 Sharepoint 2013

1-Request Managment en Sharepoint 2013

Este artículo nos introduce en la feature nueva de Sharepoint 2013 llamada Request Managment.

http://blogs.technet.com/b/hablamoss/archive/2013/03/13/sps-2013-request-management-m-243-dulo-principal-y-terminolog-237-a.aspx

2-Content Search Web Part en Sharepoint 2013

Estos artículos nos explican como usar el web part content search, y sus variantes de estilos.

21 Roll Up SharePoint 2013 Tasks with Content Search Web Part SharePoint 2010 sharepoint 2013 search service application content search web part

Content search web part - picture 3 lines

http://yalla.itgroove.net/2013/02/roll-up-sharepoint-2013-tasks-with-content-search-web-part/

http://www.sharepointnutsandbolts.com/2013/03/displaying-right-data-in-content-search.html

3-Carpeta Layouts/15 de Sharepoint 2013

Sharepoint 2013 tiene soporte para instalar soluciones de Sharepoint 2010 y obviamente de 2013. Esto lo soportar porque tiene dos carpetas layouts,

http://yalla.itgroove.net/2013/02/sharepoint-2013-_layouts15-vs-_layouts-folder-differences/

4-Licencia de Office Web Apps 2013 y Project Server 2013

El siguiente links nos aclara los tipos de licencias para OWA 2013 y PWA 2013.

http://www.brainlitter.com/2013/03/13/office-web-apps-2013-and-project-server-licensing/

5-Obtener el User Profile y sus propiedades de un usuario en Sharepoint 2013

El siguiente artículo nos indica como usar Server Object Model para obtener el user profile y sus propiedades asociadas para un usuario logueado.

http://digsharepoint.blogspot.com.ar/2013/03/how-to-createretrieve-user-profileuser.html

sábado, 2 de marzo de 2013

Links útiles #24 Sharepoint 2013

1-SkyDrive Pro

http://www.sharepointsharon.com/2013/02/an-overview-of-skydrive-pro/

2-User Permissions en MySite: restricciones de creación de uso de Mysite

http://christopherclementen.wordpress.com/2013/02/25/put-restrictions-on-mysite/

3-Cambios en el search de Sharepoint 2013

http://msdnrss.thecoderblogs.com/2013/03/changes-in-sharepoint-2013-search/

4-Data Explorer con Sharepoint 2013

http://www.spsdemo.com/blog/Lists/Posts/Post.aspx?List=c67861cd-a0d9-4ed8-9d9d-9b29652a516f&ID=371&Web=f74569c2-ae3f-42c6-a3fa-9f099dfaeb7f

5-Scripts útiles de Sharepoint 2013

SharePoint 2013: Use the Analytics namespace to log usage analytic events:

http://code.msdn.microsoft.com/SharePoint-2013-Use-the-bf5062a4

SharePoint 2013: Create and retrieve taxonomic metadata in apps for SharePoint

http://code.msdn.microsoft.com/SharePoint-2013-Create-and-1ebbdd36

SharePoint 2013: Implement live tile navigation for SharePoint lists

http://code.msdn.microsoft.com/SharePoint-2013-Implement-4dc68bf1

SharePoint 2013: Work with user profile properties in apps for SharePoint

http://code.msdn.microsoft.com/SharePoint-2013-Work-with-99d43c17

SharePoint 2013: Use SharePoint 2013 translation services from Word

http://code.msdn.microsoft.com/SharePoint-2013-Use-698b9cef

miércoles, 6 de febrero de 2013

Links útiles #58–Sharepoint 2010

1-Mantenimiento del User Profile Services en Sharepoint 2010

http://technet.microsoft.com/en-us/library/ff681014(v=office.14).aspx

2-Excel Services vs Reporting Services

http://epmxperts.wordpress.com/2013/01/25/excel-services-vs-ssrs-considerations/

3-Cambiar la url de MySite

http://fangdahai.blogspot.com.ar/2013/01/how-to-change-my-site-host-url.html

4-Jquery y web services Sharepoint 2010

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/retrieving-data-from-sharepoint-list.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/bind-html-dropdown-list-using-jquery.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/insertion-into-sharepoint-list-using.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/updating-single-record-using-jquery-and.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/deleting-more-than-one-record-using.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/updating-more-than-one-record-using.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/inserting-more-than-one-record-using.html

http://sharepoint2010tutorialnew.blogspot.com.ar/2013/01/delete-single-record-using-jquery-and.html

5-AD RMS Sharepoint 2010

http://tristanwatkins.com/inspecting-ad-rms-request-sharepoint-2010/

miércoles, 23 de enero de 2013

Links útiles #57–Sharepoint 2010

1-Importar las imágenes de los user profile de Sharepoint

http://www.sharepointusecases.com/index.php/2012/12/use-case-automatically-importing-user-profile-pictures-to-sharepoint-2013-and-2010/

http://blogs.technet.com/b/lukeb/archive/2013/01/04/sharepoint-import-a-picture-from-ad-for-the-user-profile.aspx

2-Windows Server 2012 no es soportado por Sharepoint 2010

http://support.microsoft.com/kb/2724471

3-Sequential Workflow en Sharepoint 2010 con Visual Studio

http://estarktechnologies.wordpress.com/2012/12/28/creating-sharepoint-custom-workflow-activity-through-visual-studio-2010/

http://babu143.wordpress.com/2012/12/24/creating-a-sequential-workflow-for-sharepoint-2010-using-visual-studio-a-step-by-step-guide/

4-Mostrar nombre de usuario en ves del usuario de dominio Sharepoint 2010

http://sharepoint247.wordpress.com/2012/12/30/how-to-sync-ad-properties-of-users-in-a-sharepoint-site-collection/

5-Knockout View Model – Sharepoint list

http://yetanothersharepointblog.wordpress.com/2013/01/04/updating-sharepoint-list-data-from-a-knockout-viewmodel/

6-Sharepoint vs Snapshots

http://blogs.msdn.com/b/mossbiz/archive/2013/01/14/sharepoint-vs-snapshots.aspx

7-ADLDS (Active Directory Light Directory Services) con Sharepoint 2010

http://nikspatel.wordpress.com/2013/01/18/step-by-step-configuring-adlds-user-profile-synchronization-in-sharepoint-2010/

8-Sharepoint 2010 sobre Azure

http://cloud.dzone.com/articles/how-setup-sharepoint-farm

9-Pack de forms authentication para Sharepoint 2010

http://sharepoint2010fba.codeplex.com/

10-Ribbon de Sharepoint 2010

http://ribbontabcustomization.blogspot.in/

miércoles, 26 de septiembre de 2012

Tips/Info #72 Sharepoint 2010

1-Agregar el content type “Link a Document” en un Document Set

image001

Ir la configuración del Document Set:

image005

image006

2-Obtener la password de los app pools en Windows Server 2008

Abro una línea de comandos (cmd) con permisos de administrador e ir hasta la carpeta C:Windows/system32\inetsrv\

A continuación escribo lo siguiente:

appcmd.exe list apppool “Nombre del App Pool" /text:ProcessModel.Password
Para saber los nombres de los app pool, puedes hacerlo mediante el siguiente comando: appcmd list wp
3-Ember un pdf en una página de Sharepoint 2010
Agregar un content editor y agregar el siguiente pedazo de código:
<script type="text/javascript" src="scripts/pdfobject.js"></script>
<div id="pdf1" style="width:500px; height:375px;"></div>
<script type='text/javascript'>
var myPDF = new PDFObject({
url: 'ConferenceGuide.pdf',
pdfOpenParams: {
view: 'Fit',
scrollbars: '0',
toolbar: '0',
statusbar: '0',
navpanes: '0' }
}).embed('pdf1');
</script>
La librería que se usa es la siguiente: http://pdfobject.com/
image_thumb
image_thumb1

4-Excluir cuentas de usuarios en la sincronización de perfiles


El atributo userAccountControl es usado para almacenar las opciones del objecto user en el AD. Esta propiedad informa el estado de la cuenta (disabled, bloqueada, etc)


Ir al Central Administration –> Manage Service Applications –> User Profiles service application –> Manage Synchronization Connections .Click sobre la conexión,  Edit Connection Filters


image_thumb (1)


Las posibles opciones para el atributo son:


image_thumb_4


En este link encontrará más información: http://www.harbar.net/archive/2011/02/22/323.aspx


5-Usar la columna rating en una librería


Ir a List Settings, y ingresar a la sección Rating settings


Rating_2


En esta sección, habilitar el rating para items.


Rating_3


Votar sobre un item.


Rating_4


Para que los resultados de los rating se consoliden, deberás tener iniciado el User Profile Service iniciado.





image_thumb


A continuación deberás configurar los dos siguientes jobs para consolidar ratings. Es recomendable que los dos jobs tengan un mismo intervalo de ejecución.


image_thumb1

sábado, 15 de septiembre de 2012

Tips/Info #69 Sharepoint 2010

1-Usar la clase SPMonitoredScope

SPMonitoredScope monitoredScope = new SPMonitoredScope("Probando Monitored Scope");
            {
                SPWeb myTopWeb = SPContext.Current.Site.RootWeb;
                {
                    SPList list = myTopWeb.Lists.TryGetList("Lista");
                    if (list != null)
                    {
                        SPListItem listItem = list.Items.Add();
                        listItem["Title"] = "Prueba MonitoredScope";
                        listItem.Update();
                    }
                }
            }

Nos aparecerá en el dashboard el string “Probando Monitored Scope”

2-Ubicación del FIM (ForeFront Identity Manager)

C:\Program Files\Microsoft Office Servers\14.0\Synchronization Service\UIShell\miisclient.exe

Esta utilidad se usa para debuggear la sincronización de perfiles

image_thumb_3

3-Desactivar el acceso a las páginas Forms/AllItems.aspx

Cuando se utiliza un sitio de publicación de SharePoint, las páginas de administración son accesibles a todos los usuarios, incluyendo si se tiene el tipo de acceso anónimo activado.

Se puede bloquear el acceso con una feature llamada “ViewFormsPagesLockdown”

stsadm.exe –o activatefeature –url <site collection url> -filename ViewFormPagesLockdown\feature.xml

4-DaysWorthOfActivityFeedsToKeep

Al modificar este parámetro permite reducir la cantidad de información en las tablas ActivityEventsConsolidated y ActivityEventsPublished, las cuales mantienen las actividades recientes de perfiles de usuarios. Esta propiedad se encuentra disponible desde el acumulativo de agosto de 2011.

$ups = Get-SPServiceApplication <GUID of User Profile Service Application>
$ups.DaysWorthOfActivityFeedsToKeep = 4
$ups.Update()
$ups.DaysWorthOfActivityFeedsToKeep

5-Información útil de “permission policies” sobre una web application

SC12

WebApplicationUserPolicy_thumb_5AF1DA89

images

Algunos conceptos:

Zone: Si un web site tiene múltiples zonas, tu puedes elegir a que zona se aplicará la policy. La default es todas las zonas.

Permissions: Puedes especificar los siguientes permisos: Full Control, Full Read, Deny Write,y Deny All permissions, or puedes crear un custom permission.

System: Esta setting permite que SharePoint muestre HAREPOINT\System para las actividades que realiza una cuenta de usuario que ha sido configurada para usar una policy.

Permission policy levels contiene permisos que se aplican a usuarios específicos o grupos. Puedes especificar una combinación de listas, Sites, permisos personales. Además, puedes especificar los siguientes niveles de site collection permissions:

  • Site Collection Administrator: tiene Full Control sobre el site collection entero.
  • Site Collection Auditor: tiene Full Read permission sobre el site collection.

miércoles, 12 de septiembre de 2012

Tips/Info #67 Sharepoint 2010

1-Tamaño de bases de datos de un web application

$DatabeSize = Get-SPContentDatabase -WebApplication "http://Web_applicationURL"
$DatabeSize | Format-Table Name, @{Label="Size"; Expression={$_.DiskSizeRequired / 1073741824}}

2-Redireccionar a una página desde una sandboxed solution

Cómo saben NO se pueden usar Response.Redirect, SPUtility.Redirect, Server.Transfer. Para poder hacer un redireccionamiento podremos hacer lo siguiente:

Literal literalRedirect = new Literal
   {
     Text =
        “<script  language=’javascript’>window.location.href=’/';</script>”
   };
Controls.Add(ltrl);

3-No se muestra de forma correcta el Display Name

En sharepoint se muestra el Display Name como Dominio/UserName, lo cual es erroneo.

Para solucionarlo, se puede usar la sincronización via el User Profile Syncronizacion Service. Otra posibilidad es usar el CMDLet Set-SPUser .

Set-SPUser -Identity ‘Domain\cazcon' -DisplayName ‘Christian Azcon’ –Web http://SharePointServer
Para forzar una sincronización manual de las propiedades del usuario desde el AD, se puede usar la siguiente sentencia:
Set-SPUser -Identity ‘Domain\cazcon' –Web http://SharePointServer –SyncFromAD

Más info: http://technet.microsoft.com/en-us/library/ff607827.aspx

4-Insufficient SQL database permissions for user ‘Name: SID: ImpersonationLevel: Impersonation’ in database ‘SharePoint_Config’ on SQL Server instance ‘’ The EXECUTE permission was denied on the object ‘xxxx’, database ‘SharePoint_Config’, schema ‘dbo’.

Abrir el SQL Managment Studio, ir hasta el store que lanza el error, click derecho y elegi la opción de “Properties”, en la sección de “Permissions” , asigna el permiso de “Execute” al grupo “WSS_Content_Application_Pools”.

5-Borrar logs de auditoría en Sharepoint 2010

Ejecuta SharePoint 2010 Powershell con permisos de administrador
Y ejecuta lo siguiente:
$site = Get-SPSite http://siteCollectionURL
$date = Get-Date “12/09/2012”
#verifica si la fecha es correcta
$date
$site.Audit.TrimAuditLog($date)

domingo, 2 de septiembre de 2012

Tips/info #65–Sharepoint 2010

1-Access is denied. Verify that either the Default Content Access Account has access to this repository, or add a crawl rule to crawl this repository. If the repository being crawled is a SharePoint repository, verify that the account you are using has “Full Read” permissions on the SharePoint Web Application being crawled. ( HttpStatusCode Unauthorized The request failed with HTTP status 401: Unauthorized.

Al realizar un crawl sobre el contenido de Sharepoint, nos lanza este error. La cuenta de servicios que realiza el crawl tiene permisos de read sobre el contenido (policy de full read sobre los web application). El problema surge porque está activada la opción de LoopBackRequest.

Para ello se deberá lo siguiente realizar para solucionarlo:

  • Abrir una consola de windows y abrir regedit.exe
  • Ir hasta la clave “HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Lsa“
  • Click sobre “Lsa” y crear un nuevo valor DWORD de 32 bit (si ya existe no se debe hacer nada)
  • Renombralo a “DisableLoopbackCheck”
  • Modifica el valor de “DisableLoopbackCheck” a “1″
  • A continuación  has un full crawl del contenido
  • 2-Agregar el título en las páginas mediante la propiedad “Title”

    <asp:Content ContentPlaceHolderId="PlaceHolderPageTitle" runat="server">

    <SharePointWebControls:ListProperty Property="Title" runat="server"/> -

    <SharePointWebControls:FieldValue id="PageTitle" FieldName="Title" runat="server"/>

    </asp:Content>

    En este ejemplo, si la página estaba en la librería “Pages”, el título quedará como “Pages – Nombre de la página”

    3-Prerequisitos de búsqueda de perfiles en Sharepoint 2010

  • El Search service application configurado.
  • Un deployment completo de sincronización de perfiles de usuario
  • Un Managed Metadata service application.
  • El web application de MySite Web creado y configurado
  • Craw de MySite
  • Un Search Center que use el template Enterprise Search Center.
  • 4-Saber las páginas unghosted que hay en nuestra farm.

    SELECT
          [DirName]
          ,[LeafName]
          ,[SetupPath]
          ,[SetupPathUser]
      FROM [WSS_Content].[dbo].[AllDocs]
      where ([AllDocs].[Type] = 0)
      AND ([AllDocs].SetupPath IS NOT NULL)
      AND ([AllDocs].DocFlags & 64 = 64) 

    DocFlags: http://msdn.microsoft.com/en-us/library/dd341149(v=prot.13)

    Type: http://msdn.microsoft.com/en-us/library/dd358577(v=prot.13)

    AllDocs: http://msdn.microsoft.com/en-us/library/dd304112%28v=prot.13%29

    5-Obtener el archivo ONET.XML de un sitio

    http://url_sharepoint:puerto/<Site>/_vti_bin/owssvr.dll?Cmd=GetProjSchema

    Dependiendo de dónde se encuentre un archivo Onet.xml y de si es parte de una definición de sitio o una plantilla web, el marcado del archivo realiza algunas de las siguientes acciones o todas ellas:

  • Especifica el ámbito web y las características de ámbito de colección de sitios que están integradas a los sitios web creados a partir de la definición de sitio o plantilla web.

  • Especifica los tipos de listas, páginas, archivos y elementos web integrados a los sitios web que se crean a partir de la definición de sitio o plantilla web.

  • Define las áreas de navegación superior y lateral que aparecen en la página principal y en las vistas de lista para una definición de sitio.

  • Especifica las definiciones de lista que usa cada definición de sitio y determinar su disponibilidad para crear listas en la interfaz de usuario (UI).

  • Especifica las plantillas de documento que están disponibles en la definición de sitio para crear listas de bibliotecas de documentos en la interfaz de usuario y especifica los archivos que se usan en las plantillas de documento.

  • Define los tipos base de lista de los que derivan las listas predeterminadas de SharePoint Foundation. (Solo el archivo Onet.xml global desempeña esta función. No se pueden definir tipos base de lista nuevos).

  • Especifica los componentes de SharePoint Foundation.

  • Define la sección de pie de página usada en el correo electrónico de servidor.

  • miércoles, 29 de agosto de 2012

    Tips/info #63–Sharepoint 2010

    1-Borrar perfiles de usuario Sharepoint 2010

    Los pasos serían:

    • Borrar los usuarios en el AD
    • Re sync de los perfiles de usuario
    • Ejecutar My Site Cleanup

    Más info: http://www.harbar.net/archive/2011/02/10/account-deletion-and-sharepoint-2010-user-profile-synchronization.aspx

    2-Agregar una farm administrator  via stdadm

    stsadm -o adduser -url http://central_administration:12345 -userlogin BUILTIN\Administrators -useremail admin@mail.com -group "Farm Administrators" -username "Administrators"

    3-Error con PWA: “Could not retrieve enterprise global template. Please contact your administrator.”

    Si renombraste el site de PWA en Shaepoint, posiblemente al abrir el project server, te lance el error señalado.

    “Could not retrieve enterprise global template. Please contact your administrator.”

    Para ello ingresar a regedit, y borrar todas las claves que aparecen en Profiles en el siguiente path del registro.

    HKEY_CURRENT_USER\Software\Microsoft\Office\14.0\MS Project\Profiles\
    A continuación, crear de nuevo la cuenta en el project.
    4-Problema de verificación de CLR (certificate revocation list): los sites tardan mucho en tiempo (Ej: minutos) en cargar después de hacer un iisreset
    Este problema puede ser ocasionado al consultar los certificados (CLR). Otro síntoma de este problema, puede ser que la cache de la configuración no se actualiza en los demás servers y el owstimer no trabaja de forma correcta. Verifique mediante fiddler o network  monitor si hay consultas hacia crl.microsoft.com.
    1614.clip_image003_2570E713
    Esto se debe a que el owstimer checkea varias veces la lista de certificados de revocación de certificados (CLR). Cuando carga signed assemblies, el .Net Framework checkea la lista de certificados de revocación de certificados para validar la firma de la dll que carga. La conexión a crl.microsofto.com lanza un timeout después de 30 segundos.
    Una solución es crear un archivo de configuración en el directorio bin donde esta owstimer, con el siguiente nombre owstimer.exe.config 
    y escribir lo siguiente:

    <?xml version="1.0" encoding="utf-8"?>
    <configuration>
          <runtime>
                  <generatePublisherEvidence enabled="false"/>
          </runtime>
    </configuration>

    A continuación,  has un restart del owstimer y iisreset.

    Otra solución es usar el archivo host del server

    127.0.0.1 crl.microsoft.com

    Otra posibilidades:

    http://blog.muhimbi.com/2009/04/new-approach-to-solve-sharepoints.html

    http://blogs.technet.com/b/exchange/archive/2010/05/14/3409948.aspx

     

    5-Obtener los grupos donde está un determinado usuario
    Se puede usar el servicio web “http://servername/_vti_bin/userGroup.asmx?WSDL.
    y la operación GetGroupCollectionFromUser . 
    Más información: tp://www.sumitrawat.net/2009/10/infopath-displaying-sharepoint-group.html
    Otra posibilidad es usar spservices: http://spservices.codeplex.com/wikipage?title=GetGroupCollectionFromUser

    martes, 28 de agosto de 2012

    Links útiles #48 Sharepoint 2010

    1-Debugging del search de Sharepoint 2010 con Fiddler

    http://www.ableblue.com/blog/archive/2012/01/04/troubleshooting-sharepoint-search-crawl/

    2-Página 404 custom en Sharepoint 2010

    http://salaudeen.blogspot.nl/2012/06/custom-404-page-not-found-error-page-in.html

    3-Tags & Notes sobre items de lista

    http://blog.qumsieh.ca/2012/08/21/displaying-tags-notes-on-items-in-sharepoint-2010/

    4-Mostrar grupos de Sharepoint en un formulario de infopath

    http://nickhobbs.wordpress.com/2012/08/11/sharepoint-2010-display-sharepoint-groups-in-an-infopath-form-drop-down-list-box/

    5-Documentum Vs Sharepoint

    http://www.tcs.com/SiteCollectionDocuments/White%20Papers/EntSol_Whitepapers_Core-ECM-Features-Documentum-SharePoint_11_2011.pdf

    6-Mostrar Grupos de Sharepoint en un combo de infopath

    http://nickhobbs.wordpress.com/2012/08/11/sharepoint-2010-display-sharepoint-groups-in-an-infopath-form-drop-down-list-box/

    7-Configurar ssl para el central administration

    http://www.codeproject.com/Articles/75597/How-to-Configure-SSL-Certificate-for-the-Central-A

    8-Business Connectivity Services – Conexión contra ORACLE CRUD

    http://dotnetfinder.wordpress.com/2012/08/27/how-to-connect-to-the-oracle-database-using-business-connectivity-services-bcs-in-sharepoint-2010/

    9-Editar el campo que aparece el dropdown de context menú de listas o librerías

    http://www.youtube.com/watch?v=hpQtj3_8zao

    10-Sincronización de perfiles

    IC494978

    http://technet.microsoft.com/en-us/library/gg188041.aspx

    sábado, 14 de julio de 2012

    Links útiles #45 Sharepoint 2010

    1-Subir un documento mediante web services de Sharepoint 2010

    http://norpoint.wordpress.com/2012/04/17/using-sharepoint-webservice-to-upload-a-document-from-net-web-application/

    2-SPLongOperation: para operaciones largas

    http://howtosharepoint.blogspot.com.ar/2010/04/how-to-programatically-show-processing.html

    3-Word Automation Services

    http://sprider.org/2012/07/10/developing-applications-with-sharepoint-2010-word-automation-services/

    4-Crear un custom workflow action para Sharepoint Designer

    http://www.sharepointkings.com/2012/07/creating-custom-workflow-action-for.html

    5-BDC modelo: agregar un campo combo (SQL Server)

    http://shafaqat309.wordpress.com/2012/07/10/custom-control-rendering-with-bdc-modal-and-external-list/

    6-Sharepoint 2010 y SSL

    http://blog.helloitsliam.com/Lists/Posts/Post.aspx?List=e10cb685-6b5c-4b6c-aaf4-e1d122d57174&ID=74&Web=8fe3252e-9495-44f1-b2e4-dbd7b201440b

    7-Eliminar Office Web Apps

    http://support.microsoft.com/kb/2457969

    8-Client Object Sharepoint 2013 – Sharepoint 15

    http://blog.furuknap.net/client-side-object-model-changes-in-sharepoint-2013

    9-Enviar un mail con attachments en Sharepoint 2010

    http://sharepointconnoisseur.blogspot.com.ar/2012/03/emailing-documents-as-attachments.html

    10-Policies sobre las user properties de Sharepoint 2010

    http://www.sharepointworld.in/2012/07/configurable-policy-settings-for-user.html

    11-Sharepoint 2013

    http://www.microsoft.com/en-us/download/search.aspx?q=SharePoint%202013&p=1&r=40&t=32

    http://www.microsoft.com/en-us/download/details.aspx?id=30345

    http://www.ericharlan.com/Moss_SharePoint_2007_Blog/how-to-install-sharepoint-2013-a220.html

    sábado, 23 de junio de 2012

    Links útiles #38 Sharepoint 2010

    1-Crear una feature en Sharepoint 2010

    http://salaudeen.blogspot.com.ar/2012/05/how-to-create-feature-in-sharepoint.html

    2-SSL para Sharepoint 2010

    http://www.sharepointboost.com/blog/how-to-configure-ssl-for-a-sharepoint-web-site/

    3-Business Connectivity Services y User Profiles: creando una propiedad de usuario

    https://www.nothingbutsharepoint.com/sites/devwiki/articles/Pages/SharePoint-Extend-Active-Directory-People-Search-Result-by-Using-Business-Connectivity-Service-Part-1.aspx

    4-Instalar Sharepoint 2010 con SQL Server 2012 y Windows Server 2012

    http://mohamedradwan.wordpress.com/2012/06/21/install-sharepoint-2010-with-ms-sql-server-2012-on-windows-server-2012/

    5-Script de powershell para saber el tamaño de las bases de datos de contenido (Storage Report)

    http://salaudeen.blogspot.com.ar/2012/05/sharepoint-content-databases-size.html

    6-Health Analyzer y PowerPivot

    http://whitepages.unlimitedviz.com/2012/06/the-health-analyzer-and-powerpivot-for-sharepoint/

    7-Sharepoint y DNS (+ alternate access mapping, bindings, etc)

    http://min2dmax.wordpress.com/2012/06/15/customize-sharepoint-url-using-aam-and-dns/

    8-Limpiar los valores de una user profiles en Sharepoint 2010

    http://blogs.technet.com/b/meamcs/archive/2012/06/22/cleaning-up-specific-user-profile-properties-in-sharepoint-and-avoid-indexing-them-in-search.aspx

    9-Join de listas en Sharepoint

    http://sprider.org/2012/06/22/how-to-join-two-sharepoint-lists-with-inner-join-functionality/

    http://thechriskent.com/2012/06/19/merging-data-into-a-sharepoint-list-using-ssis/

    10-KeywordQuery y FullTextSqlQuery en Sharepoint (búsqueda mediante programación)

    http://sharepoint-snippets.com/sharepoint-2010-search-programmatically-example/

    domingo, 3 de junio de 2012

    Links útiles #28–Sharepoint 2010

    1-Instalar dlls en la GAC con proyectos de Sharepoint en Visual Studio 2010

    http://sharepoint2010funfacts.blogspot.com.ar/2012/05/copying-additional-dlls-assemblies-to.html

    2-Test unit para Sharepoint 2010

    http://www.sharepointnutsandbolts.com/2012/04/sharepoint-2010-and-unit-tests-from.html

    3-Deployar páginas aspx con Sandbox solution

    http://www.akruratechnologies.com/2012/05/14/deploy-custom-aspx-page-with-sandbox-solutions-sharepoint-2010/

    4-Amazon AWS y Sharepoint 2010

    http://d36cz9buwru1tt.cloudfront.net/AWS_Amazon_SharePoint_Deployment.pdf

    5-Algunos operadores para la búsqueda y para el panel de refinamiento

    http://office.microsoft.com/en-us/sharepoint-server-help/search-for-content-HA010378166.aspx#BM4

    http://www.sharemuch.com/2012/05/30/custom-sharepoint-2010-search-refiner-displaying-range-of-choices/

    http://www.sharemuch.com/2012/05/31/more-handy-configurations-for-sharepoint-2010-search-refiners/

    6-Agregar una propiedad de metadata al perfil de usuario

    http://www.deliveron.com/blog/post/Add-a-Metadata-Property-to-User-Profiles-in-SharePoint-2010.aspx

    7-Abrir dialogo modal y refrescar la página padre

    http://yalla.itgroove.net/2012/04/open-modal-dialog-and-refresh-the-parent-page-from-custom-form-sharepoint-2010/

    8-Remover botones de la ribbon

    http://spdailytips.blogspot.ca/2011/10/various-options-to-remove-ribbon.html

    9-Deployar un event receiver para una lista específica

    http://spdailytips.blogspot.ca/2012/01/deploy-event-receiver-for-specific-list.html

    10-JQGrid y Sharepoint 2010

    http://praneethmoka.wordpress.com/2012/05/27/using-jqgrid-in-asp-netsharepoint/

    http://www.codeproject.com/Articles/343934/jqGrid-Implementation-using-SpServices-in-SharePoi

    sábado, 24 de marzo de 2012

    Links útiles #12 – Sharepoint 2010

    1-Search multilenguaje Sharepoint 2010

    http://blogs.msdn.com/b/opal/archive/2010/06/28/multilingual-search-in-sharepoint-server-2010-and-fast-search-server-2010.aspx

    2-Crear un slider de contenido con Sharepoint y Jquery

    https://www.nothingbutsharepoint.com/sites/eusp/pages/creating-your-own-content-slider-for-sharepoint.aspx

    3-Alias de SQL Server 2008 R2 con Sharepoint 2010

    http://www.sharepointassist.com/2010/02/02/configure-a-sql-server-alias-for-sharepoint-sql-server-2008/

    4-Filtrar una lista de Sharepoint con jquery y un combo

    http://request4it.wordpress.com/2012/03/13/filter-a-sharepoint-list-with-jquery/

    5-Puertos necesarios para un farm de Sharepoint 2010

    http://geeks.ms/blogs/ciin/archive/2012/03/21/sharepoint-2010-puertos-necesarios-para-un-despliegue-en-modo-granja.aspx

    6-Script para habilitar todas las features de IIS para usar Sharepoint 2010

    http://otak-otak-it.blogspot.com.ar/2012/03/automatic-iis-configuration-script-for.html

    7-Eligiendo la tecnología de reportes correcta

    http://devinknightsql.wordpress.com/2012/03/01/choosing-the-right-microsoft-reporting-technology-part-1-report-services/

    http://devinknightsql.wordpress.com/2012/03/06/choosing-the-right-microsoft-reporting-technology-part-2-excel/

    http://devinknightsql.wordpress.com/2012/03/15/choosing-the-right-microsoft-reporting-technology-part-3-powerpivot/

    http://devinknightsql.wordpress.com/2012/03/21/choosing-the-right-microsoft-reporting-technology-part-4-performancepoint/

    8-Reglas: Analizador/mantenimiento de base de datos de Sharepoint 2010

    http://www.mssqltips.com/sqlservertip/2648/sharepoint-2010-databases-maintenance-health-analyzer-rules/

    9-Configurando el Panel de refinamiento Sharepoint 2010

    http://geeks.ms/blogs/marchena/archive/2012/03/22/configuraci-243-n-del-panel-de-refinamiento-en-los-resultados-de-b-250-squeda.aspx

    10-Configurar el servicio de user profile

    http://www.anhero.org/how-to-configuration-the-user-profile-service-in-sharepoint-2010/

    11- Extendiendo la parte social de Sharepoint

    http://www.sharepointnutsandbolts.com/2012/03/extending-sharepoint-2010-social.html?utm_source=feedburner&utm_medium=feed&utm_campaign=Feed%3A+ChrisObrien+%28Chris+O%27Brien+%5BMVP+SharePoint%5D%29

    12-Crear una columna autoincremental con formato definido

    http://dlairman.wordpress.com/2011/01/10/add-a-unique-auto-incrementing-column-to-a-sharepoint-list/

    13-Desarrollando un BCS de Sharepoint 2010 con Visual Studio 2010

    http://www.sharepointbriefing.com/spcode/develop-a-business-data-connectivity-model-for-sps-2010-using-vs-2010.html

    14-Almacenar datos de configuración para los jobs

    http://blogs.microsoft.co.il/blogs/itaysk/archive/2012/03/23/storing-configuration-settings-for-timer-jobs.aspx

    15-Acceder a Sharepoint 2010 vía tecnologías de cliente.

    http://platinumdogs.wordpress.com/2012/03/20/sharepoint-displaying-list-data-with-client-side-technology-spservices-jquery-jsrender/

    16-Cómo saber a que proceso atachar el debbuger en Visual Studio 2010 y Sharepoint 2010

    http://ybbest.wordpress.com/2012/03/22/how-to-find-which-w3wp-exe-to-attach-when-debugging-your-sharepiont2010-project/

    17-Servicios disponibles en las dos versiones de Sharepoint 2010 (Standart & Enterprise)

    http://www.etechplanet.com/blog/service-applications-available-out-of-the-box-with-sharepoint-2010-products.aspx

    18-Importar las managed property y crawled property

    http://gallery.technet.microsoft.com/Import-Search-CrawledManage-1fa3d94b

    19-Optimizando la performance de reporting services

    http://sqlcat.com/sqlcat/b/technicalnotes/archive/2009/01/14/reporting-services-performance-optimizations.aspx

    20-Mejores prácticas para backups & restore de Sharepoint 2010

    http://smallcitydesign.com/sharepoint-2010-backup-and-recovery-best-practices/